
#ifndef __MEMUSAGE_H__
#define __MEMUSAGE_H__

#include "properties.h"

#define MEMUSAGE_MENU_SIZE 2

extern GnomeUIInfo memUsageMenu [];

extern GTopPropertiesHook MemUsagePropertiesHook;

void * addMemUsageView ();

#endif
